@@ -99,12 +99,14 @@ class FastLineDetector:
             A vector of specifying the beginning and ending point of a line.
             Where vector is (x1, y1, x2, y2), point 1 is the start, point 2 is the end.
             Returned lines are directed so that the brighter side is placed on left.
+        points : numpy ndarray
+            Pixels used in line detection.            
         """
         image = np.array(image)
-        segments = self.line_detection(image)
+        segments, points = self.line_detection(image)
         if segments == []:
             raise LineNotFound("The image has no line segments")
-        return np.array(segments).T
+        return np.array(segments).T, np.array(points)
 
     def line_detection(self, src):
         self._h, self._w = src.shape
@@ -116,25 +118,22 @@ class FastLineDetector:
         canny[:5, :5] = 0
         canny[self._h-5:, self._w-5:] = 0
 
+        points_all = []
         segments_all = []
         if np.all(canny == 0):
-            return segments_all
+            return segments_all, points_all
 
-        segments_tmp = []
         for r in range(self._h):
             for c in range(self._w):
-                # Skip for non-seeds
                 if canny[r,c] == 0:
                     continue
-                # Found seeds
                 pt = Point(c,r)
-                # Get point chain
                 points, canny = self.get_chained_points(canny, pt)
 
                 if len(points) - 1 < self.length_threshold:
                     points = []
                     continue
-
+                
                 segments = self.extract_segments(points, xmin=0, xmax=self._w-1, ymin=0, ymax=self._h-1)
 
                 if len(segments) == 0:
@@ -146,32 +145,31 @@ class FastLineDetector:
                         continue
                     if (seg.x1 <= 4 and seg.x2 <= 4) or (seg.y1 <= 4 and seg.y2 <= 4) or (seg.x1 >= self._w-5 and seg.x2 >= self._w-5) or (seg.y1 >= self._h-5 and seg.y2 >= self._h-5):
                         continue
-                    if self.do_merge is False:
-                        segments_all.append(seg)
-                    segments_tmp.append(seg)
+                    segments_all.append(seg)
+                    points_all.append(np.array(points))
                 points = []
                 segments = []
         
         if self.do_merge is False:
-            return segments_all
-        ith = len(segments_tmp) - 1
+            return segments_all, points_all
+        
+        ith = len(segments_all) - 1
         jth = ith - 1
         while (ith >= 1 or jth >= 0):
-            seg1 = segments_tmp[ith]
-            seg2 = segments_tmp[jth]
+            seg1 = segments_all[ith]
+            seg2 = segments_all[jth]
             seg_merged = self.merge_segments(seg1, seg2)
             if seg_merged is None:
                 jth -= 1
             else:
-                segments_tmp[jth] = seg_merged
-                del segments_tmp[ith]
+                segments_all[jth] = seg_merged
+                del segments_all[ith]
                 ith -= 1
                 jth = ith - 1
             if jth < 0:
                 ith -= 1
                 jth = ith - 1
-        segments_all = segments_tmp
-        return segments_all
+        return segments_all, points_all
 
     def get_point_chain(self, img):
         """
@@ -326,6 +324,7 @@ class FastLineDetector:
 
             is_line = True
             l_points = [ps]
+
             for j in range(1, self.length_threshold):
                 pt = Point(points[i+j].x, points[i+j].y)
                 dist = self.dist_point_line(ps, pe, pt)
@@ -365,6 +364,8 @@ class FastLineDetector:
             e1 = self.get_incident_point(a, b, ps, xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax)
             e2 = self.get_incident_point(a, b, pe, xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax)
             segments.append(Segment(e1.x, e1.y, e2.x, e2.y))
+            if self.length_threshold == 1:
+                j = 1
             skip = j
         return segments
 
